@@ -36,7 +36,7 @@ class DirectoryWatcher:
     def on_analyze_complete(self, recording):
         pass
 
-    def on_analyze_all_complete(self, recordings):
+    def on_analyze_file_complete(self, recordings):
         pass
 
     def on_error(self, recording, exception):
@@ -69,7 +69,7 @@ class DirectoryWatcher:
                 self.on_analyze_complete(recording)
             except BaseException as error:
                 self.on_error(recording, error)
-        self.on_analyze_all_complete(recordings)
+        self.on_analyze_file_complete(recordings)
 
     def watch(self):
         patterns = ["*.mp3", "*.wav"]
